\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{kn-thesis}[2016/05/25 The kn Thesis Class]  % YYYY/MM/DD
% -----------------------------------------------------------------------------
% Class options
% -----------------------------------------------------------------------------
\RequirePackage{ifthen}

% [germanthesis] - Thesis is written in German
\newboolean{germanthesis}
\setboolean{germanthesis}{false}
\DeclareOption{germanthesis}{\setboolean{germanthesis}{true}}

% [plainunnumbered] - Don't print numbers on plain pages
\newboolean{plainunnumbered}
\setboolean{plainunnumbered}{false}
\DeclareOption{plainunnumbered}{\setboolean{plainunnumbered}{true}}

% [earlydraft] - Settings for quick draft printouts
\newboolean{earlydraft}
\setboolean{earlydraft}{false}
\DeclareOption{earlydraft}{\setboolean{earlydraft}{true}}

% [watermark] - Print current time/date at bottom of each page
\newboolean{watermark}
\setboolean{watermark}{false}
\DeclareOption{watermark}{\setboolean{watermark}{true}}

% [phdthesis] - switch to PhD thesis style
\newboolean{phdthesis}
\setboolean{phdthesis}{false}
\DeclareOption{phdthesis}{\setboolean{phdthesis}{true}}

% [twoside] - double sided
\newboolean{oneside}
\setboolean{oneside}{true}
\DeclareOption{twoside}{\setboolean{oneside}{false}}

\ProcessOptions \relax
% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% Basics
% -----------------------------------------------------------------------------
% This class is based on report
\ifthenelse{\boolean{oneside}}{
\LoadClass[a4paper,11pt,onecolumn,oneside,openright,headsepline,footsepline]{scrreprt}
\RequirePackage[a4paper,left=25mm,right=30mm,top=25mm,bottom=25mm,includefoot,includehead,bindingoffset=10mm]{geometry}
}{
\LoadClass[a4paper,11pt,onecolumn,twoside,openright,headsepline,footsepline]{scrreprt}
\RequirePackage[a4paper,left=25mm,right=30mm,top=25mm,bottom=25mm,includefoot,includehead,bindingoffset=10mm]{geometry}
}

%\LoadClass[a4paper,10pt,onecolumn,twoside,openright]{report}
%\RequirePackage[a4paper,textwidth=345pt,textheight=598pt,bindingoffset=0cm,marginparwidth=3cm,hmarginratio=1:1,vmarginratio=1:1]{geometry}

% 150 percent line spacing
\RequirePackage{setspace}
\onehalfspacing



% Allow more (and larger) floats on text pages
\renewcommand{\topfraction}{0.9}  % use up to ..% of space on top
\renewcommand{\bottomfraction}{0.8}  % use up to ..% of space on bottom
\setcounter{topnumber}{4} % place up to .. on top
\setcounter{bottomnumber}{1} % place up to .. on bottom
\setcounter{totalnumber}{4} % place up to .. total
\renewcommand{\textfraction}{0.07} % allow down to ..% of text
\renewcommand{\floatpagefraction}{0.7} % fill at least ..% of float pages (must be less than \topfraction)

% Avoid widows and orphans (single line on bottom or top of page, respectively) at almost any cost
\clubpenalty = 10000
\widowpenalty = 10000
%\raggedbottom

% Default fonts
\newcommand{\mypageheadfont}{\normalfont}
\newcommand{\myheadingfont}{\normalfont}
%\RequirePackage[osf]{libertine}  % Linux Libertine
%\renewcommand{\mypageheadfont}{\normalfont\libertine}
%\renewcommand{\myheadingfont}{\normalfont\libertine}
\RequirePackage{lmodern}  % TT: Latin Modern
%\RequirePackage{helvet}  % SF: Helvetica 
%\RequirePackage[bitstream-charter,sfscaled=false]{mathdesign}  % RM: Bitstream Charter
% TODO: nicer math font?

% More encoding and typesetting fixes and tweaks
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{textcomp}
%\RequirePackage{fixltx2e}
\ifthenelse{\boolean{earlydraft}}{
	\newcommand{\mydisableprotrusion}{}
}{
	\RequirePackage[babel,protrusion=true,expansion=true,tracking=false,kerning=true,spacing=true]{microtype}
	\newcommand{\mydisableprotrusion}{\microtypesetup{protrusion=false}}
}
\RequirePackage{hyphenat}

% Graphics insertion and filetypes' order of precedence
\RequirePackage[pdftex]{graphicx}
\pdfminorversion=6
\DeclareGraphicsRule{.out.png}{png}{.out.png}{}
\ifthenelse{\boolean{earlydraft}}{
	\DeclareGraphicsExtensions{.thumb.jpg,.out.png,.pdf,.png,.jpg}
	\DeclareGraphicsRule{.thumb.jpg}{jpg}{.thumb.jpg}{}
}{
	\DeclareGraphicsExtensions{.out.png,.pdf,.png,.jpg}
}

% Typesetting URLs
\RequirePackage[lowtilde]{url}
\urlstyle{tt}

% For hyperref<->algorithm interaction
\RequirePackage{float}

% Cross-references are clickable
\RequirePackage[pdftex,bookmarks=true,bookmarksnumbered=true,colorlinks=false,pdfdisplaydoctitle=true,breaklinks=true]{hyperref}

% Captions
\RequirePackage[font=small, labelfont=bf, labelsep=endash, margin=1cm]{caption}

% Subfigures
\RequirePackage[margin=0cm]{subfig}

% Citations
\RequirePackage{cite}

% The "SI" and "num" commands for typesetting units
%\RequirePackage[sepfour=true,tophrase=\dots,per=slash,obeyall]{siunitx}
\RequirePackage[range-phrase={\dots\,},per-mode=symbol,detect-all,forbid-literal-units]{siunitx}
\DeclareSIUnit\byte{Byte}
\DeclareSIUnit\decibelm{dBm}
\DeclareSIUnit\mph{mph}

% Commands for beautiful tables
\RequirePackage{booktabs}

% Equation typesetting fixes and tweaks + proof/theorem environment
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\newtheorem{thm}{Theorem}[section]

% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% Internationalization support
% -----------------------------------------------------------------------------

% Multi-language support using Babel
\let\myoldshow\show\renewcommand{\show}{}  % temporarily disable \show command, as babeltools 2010/10/14 seems to use it
%\RequirePackage[shorthands=off]{babeltools}  % don't use any shorthands (i.e. "a will not try to
%\Requirepackage[shorthands=off,ngerman]{babel}  % don't use any shorthands (i.e. "a will not try toproduce an umlaut)
\let\show\myoldshow\renewcommand{\myoldshow}{}  % re-enable \show command
\ifthenelse{\boolean{germanthesis}}{
	\RequirePackage[american,ngerman]{babel}
}{
	\RequirePackage[ngerman,american]{babel}
}

% % Don't indent paragraphs in german theses. Instead, leave blank space between paragraphs.
\ifthenelse{\boolean{germanthesis}}{
 	\RequirePackage{parskip}
	\RequirePackage[square,sort&compress,numbers]{natbib}
}{
}

% Time and date functions
%\RequirePackage{datetime}

% Clever References
\ifthenelse{\boolean{germanthesis}}{
	\RequirePackage[ngerman]{cleveref}[2009/17/04]
	\def\cref{\Cref}
	\def\crefrange{\Crefrange}
	\crefname{lstlisting}{Listing}{Listings}
	\Crefname{lstlisting}{Listing}{Listings}
	\crefname{listing}{Listing}{Listings}
	\Crefname{listing}{Listing}{Listings}
	\crefname{algorithm}{Algorithmus}{Algorithmen}
	\Crefname{algorithm}{Algorithmus}{Algorithmen}
}{
	\RequirePackage{cleveref}[2009/17/04]
	\def\cref{\Cref}
	\def\crefrange{\Crefrange}
	\crefname{lstlisting}{listing}{listings}
	\Crefname{lstlisting}{Listing}{Listings}
	\crefname{listing}{listing}{listings}
	\Crefname{listing}{Listing}{Listings}
	\crefname{algorithm}{algorithm}{algorithms}
	\Crefname{algorithm}{Algorithm}{Algorithms}
}

% Some more language-dependent commands
\ifthenelse{\boolean{germanthesis}}{
	\RequirePackage[ngerman]{datetime}
	\newcommand{\thedate}{\today}
	\newcommand{\themonth}{\monthnamengerman}
	\newcommand{\glossarytitlename}{Abkürzungsverzeichnis}
}{
	\RequirePackage{datetime}
	\newdateformat{gerdate}{\twodigit{\THEDAY}{ }\monthname[\THEMONTH] \THEYEAR}
	\newcommand{\themonth}{\monthname}
	\newcommand{\thedate}{\gerdate\today}
%	\newcommand{\thedate}{\selectlanguage{ngerman}\today\selectlanguage{american}}
	\newcommand{\glossarytitlename}{List of Acronyms}
}

% Language-independent timestamp
\newcommand{\timestamp}{\renewcommand{\dateseparator}{-}\yyyymmdddate\today\quad\settimeformat{hhmmsstime}\currenttime}

% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% All the simple stuff goes here
% -----------------------------------------------------------------------------

% The Acronym package
\RequirePackage[printonlyused]{acronym}

% Make automatically inserted "blank pages" really blank
\RequirePackage{emptypage}

% Fix spacing around "..."
\RequirePackage{ellipsis}

% TeX ist kein Zeichenprogramm
\RequirePackage{tikz}[2010/10/13]
\usetikzlibrary{}

% Ensure that no floats are typeset before they are referenced
\RequirePackage{flafter}

% Provide the \FloatBarrier command that flushes all pending floats
\RequirePackage{placeins}

% Nag about deprecated LaTeX packages and commands
\RequirePackage[l2tabu, orthodox]{nag}

% Define command that will return current filename
\RequirePackage{currfile}

% Do not reset footnote counter on new chapter
\RequirePackage[]{chngcntr}
\counterwithout{footnote}{chapter}

% "Draft" watermark
\newcommand{\thewatermark}{\ifthenelse{\boolean{watermark}}{%
	\begin{tikzpicture}[remember picture, overlay]
		\node[anchor=south, outer sep=3.75cm] at (current page.south) {
			\color{gray}\currfilename\quad\timestamp
		};
	\end{tikzpicture}%
}{}}

% The "algorithm" environment
\RequirePackage{algorithmic}[2009/08/24]
\RequirePackage[plain,chapter]{algorithm}

\renewcommand\fs@plain{%
\def\@fs@cfont{\rmfamily}%
\let\@fs@capt\floatc@plain%
\def\@fs@pre{\hrule\relax\kern2pt}%
\def\@fs@post{}%
\def\@fs@mid{\kern2pt\hrule\relax\vspace\abovecaptionskip\relax}%
\let\@fs@iftopcapt\iffalse%
}
\floatstyle{plain}
\restylefloat{algorithm}
\ifthenelse{\boolean{germanthesis}}{
	\floatname{algorithm}{Algorithmus}
}{
}

% Chapter/section headings and page styles
%\RequirePackage[pagestyles,nobottomtitles*]{titlesec}
%\RequirePackage{titlesec}
%\ifthenelse{\boolean{plainunnumbered}}{%
%\renewpagestyle{plain}{
%	\sethead{}{}{}
%	\setfoot{}{}{\thewatermark}
%}
%}{
%\renewpagestyle{plain}{%
%	\sethead{}{}{\thewatermark}
%	\setfoot{}{\footnotesize{\thethesistype\ifthenelse{\boolean{germanthesis}}{arbeit }{thesis }\theauthor}}{\thepage}
%	\footrule
%}
%}


%\RequirePackage[automark,headsepline,footsepline,plainfootsepline]{scrpage2}
\RequirePackage[automark,headsepline,footsepline,plainfootsepline,forceoverwrite]{scrlayer-scrpage}
%,\usepackage[standardsections]{scrhack}
\clearpairofpagestyles
\lehead{\bfseries\leftmark}    %% Top left on even pages
\rohead{\bfseries\rightmark}    %% Top right on odd pages
\ofoot[\bfseries\pagemark]{\bfseries\pagemark}    %% Bottom outside on all pages
\lofoot[\footnotesize{\thethesistype\ifthenelse{\boolean{germanthesis}}{arbeit }{ Thesis }\theauthor}]{\footnotesize{\thethesistype\ifthenelse{\boolean{germanthesis}}{arbeit }{ Thesis }\theauthor}}    %% Bottom leftt on odd pages
\pagestyle{scrheadings}

%\RequirePackage{titlesec}



% rename (sub)paragraph to (sub)subsubsubsection
\let\myparagraph\paragraph
\renewcommand{\paragraph}{\FIXME{in order to avoid confusion with hyperref, \\paragraph has been renamed to \\subsubsubsection}}
\let\subsubsubsection\myparagraph
\let\mysubparagraph\subparagraph
\renewcommand{\subparagraph}{\FIXME{in order to avoid confusion with hyperref, \\subparagraph has been renamed to \\subsubsubsubsection}}
\let\subsubsubsubsection\mysubparagraph

% heading styles
%\titleformat{\chapter}[display]{\myheadingfont\huge\bfseries\titlerule\vspace{0.25cm}}{\LARGE\chaptertitlename~\thechapter}{1em}{}[\vspace{0.25cm}\titlerule]
%\titleformat{\section}{\myheadingfont\Large\bfseries}{\thesection}{1em}{}
%\titleformat{\subsection}{\myheadingfont\large\bfseries}{\thesubsection}{1em}{}
%\titleformat{\subsubsection}{\myheadingfont\normalsize\bfseries}{\thesubsubsection}{1em}{}
%\titleformat{\paragraph}{\myheadingfont\normalsize\bfseries}{\theparagraph}{1em}{}
%\titleformat{\subparagraph}{\myheadingfont\normalsize}{\thesubparagraph}{1em}{\labelitemi~}
%\titlespacing*{\chapter}{0pt}{50pt}{40pt}
%\titlespacing*{\section}{0pt}{3.5ex plus 1ex minus .2ex}{2.3ex plus .2ex}
%\titlespacing*{\subsection}{0pt}{3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex}
%\titlespacing*{\subsubsection}{0pt}{3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex} 
%\titlespacing*{\paragraph}{0pt}{3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex} 
%\titlespacing*{\subparagraph}{0pt}{3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex} 
\ifthenelse{\boolean{earlydraft}}{
	\setcounter{tocdepth}{3}
	\setcounter{secnumdepth}{3}
}{
	\setcounter{tocdepth}{3}
	\setcounter{secnumdepth}{3}
}
% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% Commands for setting author, title, ... 
% -----------------------------------------------------------------------------
\renewcommand{\author}[1]{\gdef\theauthor{#1}}
\renewcommand{\title}[1]{\gdef\thetitle{#1}}
\newcommand{\germantitle}[1]{\gdef\thegermantitle{#1}}
\newcommand{\thesistype}[1]{\gdef\thethesistype{#1}}
\newcommand{\course}[1]{\gdef\thecourse{#1}}
\newcommand{\thesiscite}[1]{\gdef\thethesiscite{#1}}
\newcommand{\birthday}[1]{\gdef\thebirthday{#1}}
\newcommand{\birthplace}[1]{\gdef\thebirthplace{#1}}
\newcommand{\thesisstart}[1]{\gdef\thethesisstart{#1}}
\newcommand{\thesisend}[1]{\gdef\thethesisend{#1}}
\newcommand{\advisors}[1]{\gdef\theadvisors{#1}}
\newcommand{\dean}[1]{\gdef\thedean{#1}}
% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% Listings
% -----------------------------------------------------------------------------
\RequirePackage[savemem]{listings}
\ifthenelse{\boolean{germanthesis}}{
	\renewcommand{\lstlistlistingname}{Listingverzeichnis}
}{
	\renewcommand{\lstlistlistingname}{List of Listings}
}
\lstset{
	language=C,
	frame=lines,
	framesep=5pt,
	captionpos=b,
	abovecaptionskip=1em,
	numbers=left,
	xleftmargin=15pt,
	framexleftmargin=15pt,
	numberstyle=\tiny,
	numbersep=5pt,
	stepnumber=1,
	fontadjust,
	tabsize=2,
	showtabs=false,
	showspaces=false,
	showstringspaces=false,
	breaklines=true,
	breakatwhitespace=true,
	keywordstyle=\color{black},
	identifierstyle=\bfseries\color{blue},
	commentstyle=\color{red},
	prebreak=\raisebox{0ex}[0ex][0ex]{\color{gray}\ensuremath{\searrow}},
	stringstyle=\bfseries\color{blue},
	basicstyle=\ttfamily\bfseries\color{black}\footnotesize
}
\lstdefinestyle{txt}{
	float,
	language=C
}
\lstdefinestyle{xml}{
	float,
	language=XML
}
% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% TOCs
% -----------------------------------------------------------------------------

% Include list-of-Xs in table of contents
\ifthenelse{\boolean{earlydraft}}{
	\RequirePackage[]{tocbibind}
	\renewcommand{\lstlistoflistings}{\begingroup\tocfile{\lstlistlistingname}{lol}\endgroup}
	\newcommand{\mymakeglossarytocentry}{\addcontentsline{toc}{chapter}{\glossarytitlename}}
	\newcommand{\mymaketodotocentry}{\todototoc}
}{
	\RequirePackage[nottoc,notlot,notlof]{tocbibind}
	\newcommand{\mymakeglossarytocentry}{}
	\newcommand{\mymaketodotocentry}{}
}

% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% Visible TODO and FIXME markers
% -----------------------------------------------------------------------------
\ifthenelse{\boolean{germanthesis}}{
	\RequirePackage[colorinlistoftodos, textwidth=3.75cm, shadow, ngerman]{todonotes}
	\@todonotes@SetTodoListName{Offene Punkte}
}{
	\RequirePackage[colorinlistoftodos, textwidth=3.75cm, shadow]{todonotes}
}
\newcounter{TODOCOUNT}
\newcommand{\TODO}[1]{\vspace{0.5em}\todo[inline, color=orange]{#1}\stepcounter{TODOCOUNT}}
\newcommand{\FIXME}[1]{\todo[size=\small, color=red]{#1}\stepcounter{TODOCOUNT}}
\AtEndDocument{
	\ifnum\value{TODOCOUNT}>0
		%\cleardoublepage
		\mymaketodotocentry\listoftodos
	\fi
}
% -----------------------------------------------------------------------------


% -----------------------------------------------------------------------------
% Title page
% -----------------------------------------------------------------------------
\newcommand{\coverpagetextsmall}[1]{%
	\@groupcoverpage@smalltextsize%
	#1%
	\vspace{0.5cm}\\%
}

\newcommand{\coverpagetextlarge}[1]{%
	\vspace{0.25cm}%
	\@groupcoverpage@largetextsize%
	#1%
	\@groupcoverpage@smalltextsize%
	\vspace{0.5cm}\\%
}
\renewcommand{\maketitle}{%

% Do some stuff we had to postpone until after e.g. \thetitle was set
\hypersetup{%
  pdftitle = {\thetitle},
  pdfsubject = {\thethesistype{} im Studiengang \thecourse},
  pdfauthor = {\theauthor},
  pdfborder=0 0 0
}

\pagenumbering{alph}

% Output cover page
{%

\tikzoption{text @groupcoverpage@ badly raggedleft}[]{\def\tikz@text@action{\raggedleft\relax}}

\begingroup
\pagestyle{empty}
\setcounter{page}\@ne

\def\@groupcoverpage@titlesize{\@setfontsize{\@groupcoverpage@titlesize}{20}{24pt}}
\def\@groupcoverpage@subtitlesize{\@setfontsize{\@groupcoverpage@subtitlesize}{14}{17pt}}
\def\@groupcoverpage@citeassize{\@setfontsize{\@groupcoverpage@citeassize}{8}{9pt}}
\def\@groupcoverpage@addressize{\@setfontsize{\@groupcoverpage@addressize}{8}{9pt}}
\def\@groupcoverpage@smalltextsize{\@setfontsize{\@groupcoverpage@smalltextsize}{14}{17pt}}
\def\@groupcoverpage@largetextsize{\@setfontsize{\@groupcoverpage@largetextsize}{20}{24pt}}

\renewcommand{\baselinestretch}{1.00}

\ifthenelse{\boolean{germanthesis}}{
\begin{tikzpicture}[remember picture,overlay] \node[xshift=0cm,yshift=0cm] at (current page.south west) { \begin{tikzpicture}[remember picture, overlay]
	\definecolor{faublue}{rgb}{0.0,0.2,0.4}
	\definecolor{tublue}{RGB}{0,51,89}

	%%% logos
	\ifthenelse{\boolean{earlydraft}}{
		% no watermark in [earlydraft] mode
	}{
	  %currently no watermark support 
	\pgftext[left,at={\pgfpoint{1.25cm}{14.14cm}}] {
	    \includegraphics[width=18.5cm]{kn/kn-watermark}
	}

	}

	\pgftext[top,right,at={\pgfpoint{19.08cm}{26 * 1cm}}] {%
		\includegraphics[width=5.5cm]{kn/tui-logo}%
	}

	\pgftext[top,left,at={\pgfpoint{2.5cm}{4cm}}] {%
		\includegraphics[height=2cm]{kn/kn-logo}%
	}

	%%% single-line text
	\pgftext[base,left,at={\pgfpoint{2.5cm}{22cm}}] {%
		\raggedright%
		\sffamily%
		\bfseries%
		\@groupcoverpage@titlesize%
		\renewcommand{\baselinestretch}{1.00}%
		~%
	}
	\pgftext[base,left,at={\pgfpoint{2.5cm}{21.4cm}}] {%
		\raggedright%
		\sffamily%
		\bfseries%
		\@groupcoverpage@largetextsize%
		\renewcommand{\baselinestretch}{1.00}%
		Fachgebiet Kommunikationsnetze%
	}

	%%% multi-line text
	\pgftext[top,left,at={\pgfpoint{2.5cm}{18cm}}] {%
		\parbox{15cm}{%
			\raggedright%
			\sffamily%
			\@groupcoverpage@largetextsize%
			\renewcommand{\baselinestretch}{1.25}%
			\coverpagetextsmall{\nohyphens{\theauthor}}%
			\coverpagetextsmall{\nohyphens{~}}%
			\coverpagetextsmall{\nohyphens{~}}%
			\coverpagetextlarge{\nohyphens{\thetitle}}%
			\coverpagetextsmall{\thethesistype{}arbeit im Studiengang \thecourse}%
			\coverpagetextsmall{\thethesisend}%
		}%
	};
	\draw[xshift=2.5cm,yshift=6cm] node [above right,text width=15cm, text badly ragged] {%
		\sffamily% 
		\@groupcoverpage@citeassize%
		\renewcommand{\baselinestretch}{1.00}%
		\begin{otherlanguage*}{ngerman}%
			Bitte zitieren als:\\%
			\nohyphens{\theauthor, ''\thetitle'', \thethesiscite{}arbeit, Technische Universität Ilmenau, Fakultät für Elektrotechnik und Informationstechnik, \themonth~\the\year.}%
		\end{otherlanguage*}
	};
 %       \draw[color=faublue, line width=0.8pt] (1.25cm,23.6cm) -- (16.7cm,23.6cm) -- (16.7cm,22.6cm) -- (17.7cm,22.6cm) -- (17.7cm,23.6cm) -- (19.75cm,23.6cm);
 	\draw[color=tublue, line width=0.8pt] (1.25cm,23.6cm) -- (19.75cm,23.6cm);
               
	\draw[color=tublue, line width=0.8pt] (1.25cm,19.6cm) -- (19.75cm,19.6cm);
        \draw[color=tublue, line width=0.8pt] (1.25cm,4.6cm) -- (19.75cm,4.6cm);

	\draw[xshift=19.08cm,yshift=4.05cm] node [below left,text width=12cm, text @groupcoverpage@ badly raggedleft] {%
		\sffamily%
		\@groupcoverpage@addressize%
		\renewcommand{\baselinestretch}{1.00}%
		Technische Universität Ilmenau\\%
		Fakultät für Elektrotechnik und Informationstechnik\\%
		Fachgebiet Kommunikationsnetze\\%
		\vspace{0.5em}%
		Helmholtzplatz 2 $\cdot$ 98693 Ilmenau $\cdot$ Deutschland%
	};
	\draw[xshift=19.08cm,yshift=1.8cm] node [above left,text width=12cm, text @groupcoverpage@ badly raggedleft] {%
		\sffamily%
		\@groupcoverpage@addressize%
		\renewcommand{\baselinestretch}{1.00}%
		\href{http://www.tu-ilmenau.de/it-kn}{http://www.tu-ilmenau.de/it-kn}%
	};
\end{tikzpicture} }; \end{tikzpicture}
}{
\begin{tikzpicture}[remember picture,overlay] \node[xshift=0cm,yshift=0cm] at (current page.south west) { \begin{tikzpicture}[remember picture, overlay]
	\definecolor{faublue}{rgb}{0.0,0.2,0.4}
	\definecolor{tublue}{RGB}{0,51,89}

	%%% logos
	\ifthenelse{\boolean{earlydraft}}{
		% no watermark in [earlydraft] mode
	}{
	  %currently no watermark support 
	\pgftext[left,at={\pgfpoint{1.25cm}{14.14cm}}] {
	    \includegraphics[width=18.5cm]{kn/kn-watermark}
	}

	}

	\pgftext[top,right,at={\pgfpoint{19.08cm}{26 * 1cm}}] {%
		\includegraphics[width=5.5cm]{kn/tui-logo}%
	}

	\pgftext[top,left,at={\pgfpoint{2.5cm}{4cm}}] {%
		\includegraphics[height=2cm]{kn/kn-logo}%
	}

	%%% single-line text
	\pgftext[base,left,at={\pgfpoint{2.5cm}{22cm}}] {%
		\raggedright%
		\sffamily%
		\bfseries%
		\@groupcoverpage@titlesize%
		\renewcommand{\baselinestretch}{1.00}%
		~%
	}
	\pgftext[base,left,at={\pgfpoint{2.5cm}{21.4cm}}] {%
		\raggedright%
		\sffamily%
		\bfseries%
		\@groupcoverpage@largetextsize%
		\renewcommand{\baselinestretch}{1.00}%
		Communication Networks Group%
	}

	%%% multi-line text
	\pgftext[top,left,at={\pgfpoint{2.5cm}{18cm}}] {%
		\parbox{15cm}{%
			\raggedright%
			\sffamily%
			\@groupcoverpage@largetextsize%
			\renewcommand{\baselinestretch}{1.25}%
			\coverpagetextsmall{\nohyphens{\theauthor}}%
			\coverpagetextsmall{\nohyphens{~}}%
			\coverpagetextsmall{\nohyphens{~}}%
			\coverpagetextlarge{\nohyphens{\thetitle}}%
			\coverpagetextsmall{\thethesistype{} Thesis in \thecourse}%
			\coverpagetextsmall{\thethesisend}%
		}%
	};
	\draw[xshift=2.5cm,yshift=6cm] node [above right,text width=15cm, text badly ragged] {%
		\sffamily% 
		\@groupcoverpage@citeassize%
		\renewcommand{\baselinestretch}{1.00}%
		\begin{otherlanguage*}{american}%
			Please cite as:\\%
			\nohyphens{\theauthor, ``\thetitle,'' \thethesiscite~Thesis~(\thethesiscite arbeit), Technische Universität Ilmenau, Department of Electrical Engineering and Information Technology, \themonth~\the\year.}%
		\end{otherlanguage*}
	};
 %       \draw[color=faublue, line width=0.8pt] (1.25cm,23.6cm) -- (16.7cm,23.6cm) -- (16.7cm,22.6cm) -- (17.7cm,22.6cm) -- (17.7cm,23.6cm) -- (19.75cm,23.6cm);
 	\draw[color=tublue, line width=0.8pt] (1.25cm,23.6cm) -- (19.75cm,23.6cm);
               
	\draw[color=tublue, line width=0.8pt] (1.25cm,19.6cm) -- (19.75cm,19.6cm);
        \draw[color=tublue, line width=0.8pt] (1.25cm,4.6cm) -- (19.75cm,4.6cm);

	\draw[xshift=19.08cm,yshift=4.05cm] node [below left,text width=12cm, text @groupcoverpage@ badly raggedleft] {%
		\sffamily%
		\@groupcoverpage@addressize%
		\renewcommand{\baselinestretch}{1.00}%
		Technische Universität Ilmenau\\%
		Department of Electrical Engineering and Information Technology\\%
		Communication Networks Group\\%
		\vspace{0.5em}%
		Helmholtzplatz 2 $\cdot$ 98693 Ilmenau $\cdot$ Germany%
	};
	\draw[xshift=19.08cm,yshift=1.8cm] node [above left,text width=12cm, text @groupcoverpage@ badly raggedleft] {%
		\sffamily%
		\@groupcoverpage@addressize%
		\renewcommand{\baselinestretch}{1.00}%
		\href{http://www.tu-ilmenau.de/it-kn}{http://www.tu-ilmenau.de/it-kn}%
	};
\end{tikzpicture} }; \end{tikzpicture}
}

\cleardoublepage
\setcounter{page}\@ne
\endgroup
}

% Title pages use single line spacing, no parindent and no parskips
\begin{singlespace}
\setlength\parindent{0pt} 
\setlength\parskip{0pt} 

%
% Now output the title page
%

\pagestyle{empty}
\pagenumbering{roman}

\ifthenelse{\boolean{phdthesis}}
{
\thispagestyle{empty}

TODO: PhD thesis title page
}
% else: Master Thesis title page
{
\thispagestyle{empty}

\vspace*{0.8cm}

\ifthenelse{\boolean{germanthesis}}{
\begin{center}

{\LARGE \textbf{\thetitle}}\\[2\baselineskip]

{\large
\thethesistype{}arbeit im Studiengang \thecourse\\[2\baselineskip]

vorgelegt von\\[2\baselineskip]

\textbf{\theauthor}\\[1\baselineskip]

geb. am \thebirthday\\
in \thebirthplace\\[2\baselineskip]

angefertigt am\\[2\baselineskip]

\textbf{Fachgebiet Kommunikationsnetze\\[0.2\baselineskip]
~\\[1.2\baselineskip]
Fakultät für Elektrotechnik und Informationstechnik\\[0.2\baselineskip]
Technische Universität Ilmenau\\[0.2\baselineskip]
}
}~\\[1\baselineskip]

\begin{tabular}{>{\raggedleft}p{5cm}p{10cm}}
Betreuer:	& \textbf{\theadvisors}\\
~ & ~\\
Abgabe der Arbeit: & \textbf{\thethesisend}\\
\end{tabular}

\end{center}
}{
\begin{center}

{\LARGE \textbf{\thetitle}}\\[2\baselineskip]

{\large
\thethesistype{} Thesis in \thecourse\\[2\baselineskip]

submitted by\\[2\baselineskip]

\textbf{\theauthor}\\[1\baselineskip]

born on \thebirthday\\
in \thebirthplace\\[2\baselineskip]

in the\\[2\baselineskip]

\textbf{Communication Networks Group\\[0.2\baselineskip]
~\\[1.2\baselineskip]
Department of Electrical Engineering\\[0.2\baselineskip]
and Information Technology\\[0.2\baselineskip]
Technische Universität Ilmenau\\[0.2\baselineskip]
}
}~\\[1\baselineskip]

\begin{tabular}{>{\raggedleft}p{5cm}p{10cm}}
Advisors:	& \textbf{\theadvisors}\\
 ~ & ~\\
Submission Date: & \textbf{\thethesisend}\\
\end{tabular}

\end{center}
}

\cleardoublepage
}
\end{singlespace}

%
% The delaration comes here
%

\ifthenelse{\boolean{phdthesis}}{}
{
\thispagestyle{empty}
\ifthenelse{\boolean{germanthesis}}{
\begin{otherlanguage*}{ngerman}
{\Large\noindent%
Erklärung \newline}

\noindent%
Ich versichere, dass ich die Arbeit ohne fremde Hilfe und ohne Benutzung anderer als der angegebenen Quellen angefertigt habe und dass die Arbeit in gleicher oder ähnlicher Form noch keiner anderen Prüfungsbehörde vorgelegen hat und von dieser als Teil einer Prüfungsleistung angenommen wurde.\\
Alle Ausführungen, die wörtlich oder sinngemäß übernommen wurden, sind als solche gekennzeichnet.
\end{otherlanguage*}

\vspace{3cm}
}{
\begin{otherlanguage*}{american}
{\Large\noindent%
Declaration \newline}

\noindent%
I declare that the work is entirely my own and was produced with no assistance from third parties.\\
I certify that the work has not been submitted in the same or any similar form for assessment to any other examining body and all references, direct and indirect, are indicated as such and have been cited accordingly.
\end{otherlanguage*}

\vspace{3cm}
}

\noindent%
(\theauthor)\\
Ilmenau, \today

\cleardoublepage
}

\pagestyle{scrheadings}

}
% -----------------------------------------------------------------------------

